# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.cosmos.query.v1 import query_pb2 as cosmos_dot_query_dot_v1_dot_query__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmwasm/wasm/v1/query.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1b\x63osmos/query/v1/query.proto\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\"N\n\x18QueryContractInfoRequest\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\"\xad\x01\n\x19QueryContractInfoResponse\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12V\n\rcontract_info\x18\x02 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.ContractInfoB\x11\xc8\xde\x1f\x00\xd0\xde\x1f\x01\xea\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0c\x63ontractInfo:\x04\xe8\xa0\x1f\x01\"\x99\x01\n\x1bQueryContractHistoryRequest\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xb8\x01\n\x1cQueryContractHistoryResponse\x12O\n\x07\x65ntries\x18\x01 \x03(\x0b\x32*.cosmwasm.wasm.v1.ContractCodeHistoryEntryB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x07\x65ntries\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"~\n\x1bQueryContractsByCodeRequest\x12\x17\n\x07\x63ode_id\x18\x01 \x01(\x04R\x06\x63odeId\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\x9f\x01\n\x1cQueryContractsByCodeResponse\x12\x36\n\tcontracts\x18\x01 \x03(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tcontracts\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x9a\x01\n\x1cQueryAllContractStateRequest\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xa4\x01\n\x1dQueryAllContractStateResponse\x12:\n\x06models\x18\x01 \x03(\x0b\x32\x17.cosmwasm.wasm.v1.ModelB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06models\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"q\n\x1cQueryRawContractStateRequest\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12\x1d\n\nquery_data\x18\x02 \x01(\x0cR\tqueryData\"3\n\x1dQueryRawContractStateResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\"\x9b\x01\n\x1eQuerySmartContractStateRequest\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12\x45\n\nquery_data\x18\x02 \x01(\x0c\x42&\xfa\xde\x1f\x12RawContractMessage\x9a\xe7\xb0*\x0binline_jsonR\tqueryData\"]\n\x1fQuerySmartContractStateResponse\x12:\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42&\xfa\xde\x1f\x12RawContractMessage\x9a\xe7\xb0*\x0binline_jsonR\x04\x64\x61ta\"+\n\x10QueryCodeRequest\x12\x17\n\x07\x63ode_id\x18\x01 \x01(\x04R\x06\x63odeId\"\xb8\x02\n\x10\x43odeInfoResponse\x12)\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\x10\xe2\xde\x1f\x06\x43odeID\xea\xde\x1f\x02idR\x06\x63odeId\x12\x32\n\x07\x63reator\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x63reator\x12Q\n\tdata_hash\x18\x03 \x01(\x0c\x42\x34\xfa\xde\x1f\x30github.com/cometbft/cometbft/libs/bytes.HexBytesR\x08\x64\x61taHash\x12`\n\x16instantiate_permission\x18\x06 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x15instantiatePermission:\x04\xe8\xa0\x1f\x01J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\"\x82\x01\n\x11QueryCodeResponse\x12I\n\tcode_info\x18\x01 \x01(\x0b\x32\".cosmwasm.wasm.v1.CodeInfoResponseB\x08\xd0\xde\x1f\x01\xea\xde\x1f\x00R\x08\x63odeInfo\x12\x1c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x42\x08\xea\xde\x1f\x04\x64\x61taR\x04\x64\x61ta:\x04\xe8\xa0\x1f\x01\"[\n\x11QueryCodesRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xab\x01\n\x12QueryCodesResponse\x12L\n\ncode_infos\x18\x01 \x03(\x0b\x32\".cosmwasm.wasm.v1.CodeInfoResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\tcodeInfos\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"a\n\x17QueryPinnedCodesRequest\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\x8b\x01\n\x18QueryPinnedCodesResponse\x12&\n\x08\x63ode_ids\x18\x01 \x03(\x04\x42\x0b\xe2\xde\x1f\x07\x43odeIDsR\x07\x63odeIds\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x14\n\x12QueryParamsRequest\"R\n\x13QueryParamsResponse\x12;\n\x06params\x18\x01 \x01(\x0b\x32\x18.cosmwasm.wasm.v1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06params\"\xab\x01\n\x1eQueryContractsByCreatorRequest\x12\x41\n\x0f\x63reator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x0e\x63reatorAddress\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xb3\x01\n\x1fQueryContractsByCreatorResponse\x12G\n\x12\x63ontract_addresses\x18\x01 \x03(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x11\x63ontractAddresses\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\xab\x01\n\x18QueryBuildAddressRequest\x12\x1b\n\tcode_hash\x18\x01 \x01(\tR\x08\x63odeHash\x12\x41\n\x0f\x63reator_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x0e\x63reatorAddress\x12\x12\n\x04salt\x18\x03 \x01(\tR\x04salt\x12\x1b\n\tinit_args\x18\x04 \x01(\x0cR\x08initArgs\"O\n\x19QueryBuildAddressResponse\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress2\x97\x0f\n\x05Query\x12\x9a\x01\n\x0c\x43ontractInfo\x12*.cosmwasm.wasm.v1.QueryContractInfoRequest\x1a+.cosmwasm.wasm.v1.QueryContractInfoResponse\"1\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02&\x12$/cosmwasm/wasm/v1/contract/{address}\x12\xab\x01\n\x0f\x43ontractHistory\x12-.cosmwasm.wasm.v1.QueryContractHistoryRequest\x1a..cosmwasm.wasm.v1.QueryContractHistoryResponse\"9\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02.\x12,/cosmwasm/wasm/v1/contract/{address}/history\x12\xa9\x01\n\x0f\x43ontractsByCode\x12-.cosmwasm.wasm.v1.QueryContractsByCodeRequest\x1a..cosmwasm.wasm.v1.QueryContractsByCodeResponse\"7\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02,\x12*/cosmwasm/wasm/v1/code/{code_id}/contracts\x12\xac\x01\n\x10\x41llContractState\x12..cosmwasm.wasm.v1.QueryAllContractStateRequest\x1a/.cosmwasm.wasm.v1.QueryAllContractStateResponse\"7\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02,\x12*/cosmwasm/wasm/v1/contract/{address}/state\x12\xb7\x01\n\x10RawContractState\x12..cosmwasm.wasm.v1.QueryRawContractStateRequest\x1a/.cosmwasm.wasm.v1.QueryRawContractStateResponse\"B\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x37\x12\x35/cosmwasm/wasm/v1/contract/{address}/raw/{query_data}\x12\xba\x01\n\x12SmartContractState\x12\x30.cosmwasm.wasm.v1.QuerySmartContractStateRequest\x1a\x31.cosmwasm.wasm.v1.QuerySmartContractStateResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/cosmwasm/wasm/v1/contract/{address}/smart/{query_data}\x12~\n\x04\x43ode\x12\".cosmwasm.wasm.v1.QueryCodeRequest\x1a#.cosmwasm.wasm.v1.QueryCodeResponse\"-\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\"\x12 /cosmwasm/wasm/v1/code/{code_id}\x12w\n\x05\x43odes\x12#.cosmwasm.wasm.v1.QueryCodesRequest\x1a$.cosmwasm.wasm.v1.QueryCodesResponse\"#\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x18\x12\x16/cosmwasm/wasm/v1/code\x12\x91\x01\n\x0bPinnedCodes\x12).cosmwasm.wasm.v1.QueryPinnedCodesRequest\x1a*.cosmwasm.wasm.v1.QueryPinnedCodesResponse\"+\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02 \x12\x1e/cosmwasm/wasm/v1/codes/pinned\x12\x82\x01\n\x06Params\x12$.cosmwasm.wasm.v1.QueryParamsRequest\x1a%.cosmwasm.wasm.v1.QueryParamsResponse\"+\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02 \x12\x1e/cosmwasm/wasm/v1/codes/params\x12\xbd\x01\n\x12\x43ontractsByCreator\x12\x30.cosmwasm.wasm.v1.QueryContractsByCreatorRequest\x1a\x31.cosmwasm.wasm.v1.QueryContractsByCreatorResponse\"B\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x37\x12\x35/cosmwasm/wasm/v1/contracts/creator/{creator_address}\x12\x9e\x01\n\x0c\x42uildAddress\x12*.cosmwasm.wasm.v1.QueryBuildAddressRequest\x1a+.cosmwasm.wasm.v1.QueryBuildAddressResponse\"5\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02*\x12(/cosmwasm/wasm/v1/contract/build_addressB\xb4\x01\n\x14\x63om.cosmwasm.wasm.v1B\nQueryProtoP\x01Z&github.com/CosmWasm/wasmd/x/wasm/types\xa2\x02\x03\x43WX\xaa\x02\x10\x43osmwasm.Wasm.V1\xca\x02\x10\x43osmwasm\\Wasm\\V1\xe2\x02\x1c\x43osmwasm\\Wasm\\V1\\GPBMetadata\xea\x02\x12\x43osmwasm::Wasm::V1\xc8\xe1\x1e\x00\xa8\xe2\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.cosmwasm.wasm.v1B\nQueryProtoP\001Z&github.com/CosmWasm/wasmd/x/wasm/types\242\002\003CWX\252\002\020Cosmwasm.Wasm.V1\312\002\020Cosmwasm\\Wasm\\V1\342\002\034Cosmwasm\\Wasm\\V1\\GPBMetadata\352\002\022Cosmwasm::Wasm::V1\310\341\036\000\250\342\036\000'
  _globals['_QUERYCONTRACTINFOREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYCONTRACTINFOREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYCONTRACTINFORESPONSE'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYCONTRACTINFORESPONSE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYCONTRACTINFORESPONSE'].fields_by_name['contract_info']._loaded_options = None
  _globals['_QUERYCONTRACTINFORESPONSE'].fields_by_name['contract_info']._serialized_options = b'\310\336\037\000\320\336\037\001\352\336\037\000\250\347\260*\001'
  _globals['_QUERYCONTRACTINFORESPONSE']._loaded_options = None
  _globals['_QUERYCONTRACTINFORESPONSE']._serialized_options = b'\350\240\037\001'
  _globals['_QUERYCONTRACTHISTORYREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYCONTRACTHISTORYREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYCONTRACTHISTORYRESPONSE'].fields_by_name['entries']._loaded_options = None
  _globals['_QUERYCONTRACTHISTORYRESPONSE'].fields_by_name['entries']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYCONTRACTSBYCODERESPONSE'].fields_by_name['contracts']._loaded_options = None
  _globals['_QUERYCONTRACTSBYCODERESPONSE'].fields_by_name['contracts']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYALLCONTRACTSTATEREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYALLCONTRACTSTATEREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYALLCONTRACTSTATERESPONSE'].fields_by_name['models']._loaded_options = None
  _globals['_QUERYALLCONTRACTSTATERESPONSE'].fields_by_name['models']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYRAWCONTRACTSTATEREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYRAWCONTRACTSTATEREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYSMARTCONTRACTSTATEREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYSMARTCONTRACTSTATEREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYSMARTCONTRACTSTATEREQUEST'].fields_by_name['query_data']._loaded_options = None
  _globals['_QUERYSMARTCONTRACTSTATEREQUEST'].fields_by_name['query_data']._serialized_options = b'\372\336\037\022RawContractMessage\232\347\260*\013inline_json'
  _globals['_QUERYSMARTCONTRACTSTATERESPONSE'].fields_by_name['data']._loaded_options = None
  _globals['_QUERYSMARTCONTRACTSTATERESPONSE'].fields_by_name['data']._serialized_options = b'\372\336\037\022RawContractMessage\232\347\260*\013inline_json'
  _globals['_CODEINFORESPONSE'].fields_by_name['code_id']._loaded_options = None
  _globals['_CODEINFORESPONSE'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID\352\336\037\002id'
  _globals['_CODEINFORESPONSE'].fields_by_name['creator']._loaded_options = None
  _globals['_CODEINFORESPONSE'].fields_by_name['creator']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_CODEINFORESPONSE'].fields_by_name['data_hash']._loaded_options = None
  _globals['_CODEINFORESPONSE'].fields_by_name['data_hash']._serialized_options = b'\372\336\0370github.com/cometbft/cometbft/libs/bytes.HexBytes'
  _globals['_CODEINFORESPONSE'].fields_by_name['instantiate_permission']._loaded_options = None
  _globals['_CODEINFORESPONSE'].fields_by_name['instantiate_permission']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_CODEINFORESPONSE']._loaded_options = None
  _globals['_CODEINFORESPONSE']._serialized_options = b'\350\240\037\001'
  _globals['_QUERYCODERESPONSE'].fields_by_name['code_info']._loaded_options = None
  _globals['_QUERYCODERESPONSE'].fields_by_name['code_info']._serialized_options = b'\320\336\037\001\352\336\037\000'
  _globals['_QUERYCODERESPONSE'].fields_by_name['data']._loaded_options = None
  _globals['_QUERYCODERESPONSE'].fields_by_name['data']._serialized_options = b'\352\336\037\004data'
  _globals['_QUERYCODERESPONSE']._loaded_options = None
  _globals['_QUERYCODERESPONSE']._serialized_options = b'\350\240\037\001'
  _globals['_QUERYCODESRESPONSE'].fields_by_name['code_infos']._loaded_options = None
  _globals['_QUERYCODESRESPONSE'].fields_by_name['code_infos']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYPINNEDCODESRESPONSE'].fields_by_name['code_ids']._loaded_options = None
  _globals['_QUERYPINNEDCODESRESPONSE'].fields_by_name['code_ids']._serialized_options = b'\342\336\037\007CodeIDs'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYCONTRACTSBYCREATORREQUEST'].fields_by_name['creator_address']._loaded_options = None
  _globals['_QUERYCONTRACTSBYCREATORREQUEST'].fields_by_name['creator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYCONTRACTSBYCREATORRESPONSE'].fields_by_name['contract_addresses']._loaded_options = None
  _globals['_QUERYCONTRACTSBYCREATORRESPONSE'].fields_by_name['contract_addresses']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYBUILDADDRESSREQUEST'].fields_by_name['creator_address']._loaded_options = None
  _globals['_QUERYBUILDADDRESSREQUEST'].fields_by_name['creator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYBUILDADDRESSRESPONSE'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYBUILDADDRESSRESPONSE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERY'].methods_by_name['ContractInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ContractInfo']._serialized_options = b'\210\347\260*\001\202\323\344\223\002&\022$/cosmwasm/wasm/v1/contract/{address}'
  _globals['_QUERY'].methods_by_name['ContractHistory']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ContractHistory']._serialized_options = b'\210\347\260*\001\202\323\344\223\002.\022,/cosmwasm/wasm/v1/contract/{address}/history'
  _globals['_QUERY'].methods_by_name['ContractsByCode']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ContractsByCode']._serialized_options = b'\210\347\260*\001\202\323\344\223\002,\022*/cosmwasm/wasm/v1/code/{code_id}/contracts'
  _globals['_QUERY'].methods_by_name['AllContractState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllContractState']._serialized_options = b'\210\347\260*\001\202\323\344\223\002,\022*/cosmwasm/wasm/v1/contract/{address}/state'
  _globals['_QUERY'].methods_by_name['RawContractState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RawContractState']._serialized_options = b'\210\347\260*\001\202\323\344\223\0027\0225/cosmwasm/wasm/v1/contract/{address}/raw/{query_data}'
  _globals['_QUERY'].methods_by_name['SmartContractState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SmartContractState']._serialized_options = b'\202\323\344\223\0029\0227/cosmwasm/wasm/v1/contract/{address}/smart/{query_data}'
  _globals['_QUERY'].methods_by_name['Code']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Code']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\"\022 /cosmwasm/wasm/v1/code/{code_id}'
  _globals['_QUERY'].methods_by_name['Codes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Codes']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\030\022\026/cosmwasm/wasm/v1/code'
  _globals['_QUERY'].methods_by_name['PinnedCodes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PinnedCodes']._serialized_options = b'\210\347\260*\001\202\323\344\223\002 \022\036/cosmwasm/wasm/v1/codes/pinned'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\210\347\260*\001\202\323\344\223\002 \022\036/cosmwasm/wasm/v1/codes/params'
  _globals['_QUERY'].methods_by_name['ContractsByCreator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ContractsByCreator']._serialized_options = b'\210\347\260*\001\202\323\344\223\0027\0225/cosmwasm/wasm/v1/contracts/creator/{creator_address}'
  _globals['_QUERY'].methods_by_name['BuildAddress']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BuildAddress']._serialized_options = b'\210\347\260*\001\202\323\344\223\002*\022(/cosmwasm/wasm/v1/contract/build_address'
  _globals['_QUERYCONTRACTINFOREQUEST']._serialized_start=251
  _globals['_QUERYCONTRACTINFOREQUEST']._serialized_end=329
  _globals['_QUERYCONTRACTINFORESPONSE']._serialized_start=332
  _globals['_QUERYCONTRACTINFORESPONSE']._serialized_end=505
  _globals['_QUERYCONTRACTHISTORYREQUEST']._serialized_start=508
  _globals['_QUERYCONTRACTHISTORYREQUEST']._serialized_end=661
  _globals['_QUERYCONTRACTHISTORYRESPONSE']._serialized_start=664
  _globals['_QUERYCONTRACTHISTORYRESPONSE']._serialized_end=848
  _globals['_QUERYCONTRACTSBYCODEREQUEST']._serialized_start=850
  _globals['_QUERYCONTRACTSBYCODEREQUEST']._serialized_end=976
  _globals['_QUERYCONTRACTSBYCODERESPONSE']._serialized_start=979
  _globals['_QUERYCONTRACTSBYCODERESPONSE']._serialized_end=1138
  _globals['_QUERYALLCONTRACTSTATEREQUEST']._serialized_start=1141
  _globals['_QUERYALLCONTRACTSTATEREQUEST']._serialized_end=1295
  _globals['_QUERYALLCONTRACTSTATERESPONSE']._serialized_start=1298
  _globals['_QUERYALLCONTRACTSTATERESPONSE']._serialized_end=1462
  _globals['_QUERYRAWCONTRACTSTATEREQUEST']._serialized_start=1464
  _globals['_QUERYRAWCONTRACTSTATEREQUEST']._serialized_end=1577
  _globals['_QUERYRAWCONTRACTSTATERESPONSE']._serialized_start=1579
  _globals['_QUERYRAWCONTRACTSTATERESPONSE']._serialized_end=1630
  _globals['_QUERYSMARTCONTRACTSTATEREQUEST']._serialized_start=1633
  _globals['_QUERYSMARTCONTRACTSTATEREQUEST']._serialized_end=1788
  _globals['_QUERYSMARTCONTRACTSTATERESPONSE']._serialized_start=1790
  _globals['_QUERYSMARTCONTRACTSTATERESPONSE']._serialized_end=1883
  _globals['_QUERYCODEREQUEST']._serialized_start=1885
  _globals['_QUERYCODEREQUEST']._serialized_end=1928
  _globals['_CODEINFORESPONSE']._serialized_start=1931
  _globals['_CODEINFORESPONSE']._serialized_end=2243
  _globals['_QUERYCODERESPONSE']._serialized_start=2246
  _globals['_QUERYCODERESPONSE']._serialized_end=2376
  _globals['_QUERYCODESREQUEST']._serialized_start=2378
  _globals['_QUERYCODESREQUEST']._serialized_end=2469
  _globals['_QUERYCODESRESPONSE']._serialized_start=2472
  _globals['_QUERYCODESRESPONSE']._serialized_end=2643
  _globals['_QUERYPINNEDCODESREQUEST']._serialized_start=2645
  _globals['_QUERYPINNEDCODESREQUEST']._serialized_end=2742
  _globals['_QUERYPINNEDCODESRESPONSE']._serialized_start=2745
  _globals['_QUERYPINNEDCODESRESPONSE']._serialized_end=2884
  _globals['_QUERYPARAMSREQUEST']._serialized_start=2886
  _globals['_QUERYPARAMSREQUEST']._serialized_end=2906
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=2908
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=2990
  _globals['_QUERYCONTRACTSBYCREATORREQUEST']._serialized_start=2993
  _globals['_QUERYCONTRACTSBYCREATORREQUEST']._serialized_end=3164
  _globals['_QUERYCONTRACTSBYCREATORRESPONSE']._serialized_start=3167
  _globals['_QUERYCONTRACTSBYCREATORRESPONSE']._serialized_end=3346
  _globals['_QUERYBUILDADDRESSREQUEST']._serialized_start=3349
  _globals['_QUERYBUILDADDRESSREQUEST']._serialized_end=3520
  _globals['_QUERYBUILDADDRESSRESPONSE']._serialized_start=3522
  _globals['_QUERYBUILDADDRESSRESPONSE']._serialized_end=3601
  _globals['_QUERY']._serialized_start=3604
  _globals['_QUERY']._serialized_end=5547
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/erc20/v1beta1/erc20.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/erc20/v1beta1/erc20.proto\x12\x17injective.erc20.v1beta1\"O\n\tTokenPair\x12\x1d\n\nbank_denom\x18\x01 \x01(\tR\tbankDenom\x12#\n\rerc20_address\x18\x02 \x01(\tR\x0c\x65rc20AddressB\xf4\x01\n\x1b\x63om.injective.erc20.v1beta1B\nErc20ProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/erc20/types\xa2\x02\x03IEX\xaa\x02\x17Injective.Erc20.V1beta1\xca\x02\x17Injective\\Erc20\\V1beta1\xe2\x02#Injective\\Erc20\\V1beta1\\GPBMetadata\xea\x02\x19Injective::Erc20::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.erc20.v1beta1.erc20_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective.erc20.v1beta1B\nErc20ProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/erc20/types\242\002\003IEX\252\002\027Injective.Erc20.V1beta1\312\002\027Injective\\Erc20\\V1beta1\342\002#Injective\\Erc20\\V1beta1\\GPBMetadata\352\002\031Injective::Erc20::V1beta1'
  _globals['_TOKENPAIR']._serialized_start=64
  _globals['_TOKENPAIR']._serialized_end=143
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/color.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17google/type/color.proto\x12\x0bgoogle.type\x1a\x1egoogle/protobuf/wrappers.proto\"v\n\x05\x43olor\x12\x10\n\x03red\x18\x01 \x01(\x02R\x03red\x12\x14\n\x05green\x18\x02 \x01(\x02R\x05green\x12\x12\n\x04\x62lue\x18\x03 \x01(\x02R\x04\x62lue\x12\x31\n\x05\x61lpha\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x05\x61lphaB\xa5\x01\n\x0f\x63om.google.typeB\nColorProtoP\x01Z6google.golang.org/genproto/googleapis/type/color;color\xf8\x01\x01\xa2\x02\x03GTX\xaa\x02\x0bGoogle.Type\xca\x02\x0bGoogle\\Type\xe2\x02\x17Google\\Type\\GPBMetadata\xea\x02\x0cGoogle::Typeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.color_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.google.typeB\nColorProtoP\001Z6google.golang.org/genproto/googleapis/type/color;color\370\001\001\242\002\003GTX\252\002\013Google.Type\312\002\013Google\\Type\342\002\027Google\\Type\\GPBMetadata\352\002\014Google::Type'
  _globals['_COLOR']._serialized_start=72
  _globals['_COLOR']._serialized_end=190
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.injective.auction.v1beta1 import auction_pb2 as injective_dot_auction_dot_v1beta1_dot_auction__pb2
from pyinjective.proto.injective.auction.v1beta1 import genesis_pb2 as injective_dot_auction_dot_v1beta1_dot_genesis__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/auction/v1beta1/query.proto\x12\x19injective.auction.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\'injective/auction/v1beta1/auction.proto\x1a\'injective/auction/v1beta1/genesis.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x1b\n\x19QueryAuctionParamsRequest\"]\n\x1aQueryAuctionParamsResponse\x12?\n\x06params\x18\x01 \x01(\x0b\x32!.injective.auction.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\"\n QueryCurrentAuctionBasketRequest\"\xcd\x02\n!QueryCurrentAuctionBasketResponse\x12\x63\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsR\x06\x61mount\x12\"\n\x0c\x61uctionRound\x18\x02 \x01(\x04R\x0c\x61uctionRound\x12.\n\x12\x61uctionClosingTime\x18\x03 \x01(\x04R\x12\x61uctionClosingTime\x12$\n\rhighestBidder\x18\x04 \x01(\tR\rhighestBidder\x12I\n\x10highestBidAmount\x18\x05 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x10highestBidAmount\"\x19\n\x17QueryModuleStateRequest\"Y\n\x18QueryModuleStateResponse\x12=\n\x05state\x18\x01 \x01(\x0b\x32\'.injective.auction.v1beta1.GenesisStateR\x05state\"\x1f\n\x1dQueryLastAuctionResultRequest\"~\n\x1eQueryLastAuctionResultResponse\x12\\\n\x13last_auction_result\x18\x01 \x01(\x0b\x32,.injective.auction.v1beta1.LastAuctionResultR\x11lastAuctionResult2\xe4\x05\n\x05Query\x12\xa7\x01\n\rAuctionParams\x12\x34.injective.auction.v1beta1.QueryAuctionParamsRequest\x1a\x35.injective.auction.v1beta1.QueryAuctionParamsResponse\")\x82\xd3\xe4\x93\x02#\x12!/injective/auction/v1beta1/params\x12\xbc\x01\n\x14\x43urrentAuctionBasket\x12;.injective.auction.v1beta1.QueryCurrentAuctionBasketRequest\x1a<.injective.auction.v1beta1.QueryCurrentAuctionBasketResponse\")\x82\xd3\xe4\x93\x02#\x12!/injective/auction/v1beta1/basket\x12\xae\x01\n\x12\x41uctionModuleState\x12\x32.injective.auction.v1beta1.QueryModuleStateRequest\x1a\x33.injective.auction.v1beta1.QueryModuleStateResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/injective/auction/v1beta1/module_state\x12\xc0\x01\n\x11LastAuctionResult\x12\x38.injective.auction.v1beta1.QueryLastAuctionResultRequest\x1a\x39.injective.auction.v1beta1.QueryLastAuctionResultResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./injective/auction/v1beta1/last_auction_resultB\x80\x02\n\x1d\x63om.injective.auction.v1beta1B\nQueryProtoP\x01ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types\xa2\x02\x03IAX\xaa\x02\x19Injective.Auction.V1beta1\xca\x02\x19Injective\\Auction\\V1beta1\xe2\x02%Injective\\Auction\\V1beta1\\GPBMetadata\xea\x02\x1bInjective::Auction::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.auction.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.injective.auction.v1beta1B\nQueryProtoP\001ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types\242\002\003IAX\252\002\031Injective.Auction.V1beta1\312\002\031Injective\\Auction\\V1beta1\342\002%Injective\\Auction\\V1beta1\\GPBMetadata\352\002\033Injective::Auction::V1beta1'
  _globals['_QUERYAUCTIONPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYAUCTIONPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCURRENTAUCTIONBASKETRESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_QUERYCURRENTAUCTIONBASKETRESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_QUERYCURRENTAUCTIONBASKETRESPONSE'].fields_by_name['highestBidAmount']._loaded_options = None
  _globals['_QUERYCURRENTAUCTIONBASKETRESPONSE'].fields_by_name['highestBidAmount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_QUERY'].methods_by_name['AuctionParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AuctionParams']._serialized_options = b'\202\323\344\223\002#\022!/injective/auction/v1beta1/params'
  _globals['_QUERY'].methods_by_name['CurrentAuctionBasket']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CurrentAuctionBasket']._serialized_options = b'\202\323\344\223\002#\022!/injective/auction/v1beta1/basket'
  _globals['_QUERY'].methods_by_name['AuctionModuleState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AuctionModuleState']._serialized_options = b'\202\323\344\223\002)\022\'/injective/auction/v1beta1/module_state'
  _globals['_QUERY'].methods_by_name['LastAuctionResult']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LastAuctionResult']._serialized_options = b'\202\323\344\223\0020\022./injective/auction/v1beta1/last_auction_result'
  _globals['_QUERYAUCTIONPARAMSREQUEST']._serialized_start=234
  _globals['_QUERYAUCTIONPARAMSREQUEST']._serialized_end=261
  _globals['_QUERYAUCTIONPARAMSRESPONSE']._serialized_start=263
  _globals['_QUERYAUCTIONPARAMSRESPONSE']._serialized_end=356
  _globals['_QUERYCURRENTAUCTIONBASKETREQUEST']._serialized_start=358
  _globals['_QUERYCURRENTAUCTIONBASKETREQUEST']._serialized_end=392
  _globals['_QUERYCURRENTAUCTIONBASKETRESPONSE']._serialized_start=395
  _globals['_QUERYCURRENTAUCTIONBASKETRESPONSE']._serialized_end=728
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=730
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=755
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=757
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=846
  _globals['_QUERYLASTAUCTIONRESULTREQUEST']._serialized_start=848
  _globals['_QUERYLASTAUCTIONRESULTREQUEST']._serialized_end=879
  _globals['_QUERYLASTAUCTIONRESULTRESPONSE']._serialized_start=881
  _globals['_QUERYLASTAUCTIONRESULTRESPONSE']._serialized_end=1007
  _globals['_QUERY']._serialized_start=1010
  _globals['_QUERY']._serialized_end=1750
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/account.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/types/v1beta1/account.proto\x12\x17injective.types.v1beta1\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\"\xcf\x01\n\nEthAccount\x12`\n\x0c\x62\x61se_account\x18\x01 \x01(\x0b\x32 .cosmos.auth.v1beta1.BaseAccountB\x1b\xd0\xde\x1f\x01\xf2\xde\x1f\x13yaml:\"base_account\"R\x0b\x62\x61seAccount\x12\x31\n\tcode_hash\x18\x02 \x01(\x0c\x42\x14\xf2\xde\x1f\x10yaml:\"code_hash\"R\x08\x63odeHash:,\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1c\x63osmos.auth.v1beta1.AccountIB\xe8\x01\n\x1b\x63om.injective.types.v1beta1B\x0c\x41\x63\x63ountProtoP\x01Z=github.com/InjectiveLabs/injective-core/injective-chain/types\xa2\x02\x03ITX\xaa\x02\x17Injective.Types.V1beta1\xca\x02\x17Injective\\Types\\V1beta1\xe2\x02#Injective\\Types\\V1beta1\\GPBMetadata\xea\x02\x19Injective::Types::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.types.v1beta1.account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective.types.v1beta1B\014AccountProtoP\001Z=github.com/InjectiveLabs/injective-core/injective-chain/types\242\002\003ITX\252\002\027Injective.Types.V1beta1\312\002\027Injective\\Types\\V1beta1\342\002#Injective\\Types\\V1beta1\\GPBMetadata\352\002\031Injective::Types::V1beta1'
  _globals['_ETHACCOUNT'].fields_by_name['base_account']._loaded_options = None
  _globals['_ETHACCOUNT'].fields_by_name['base_account']._serialized_options = b'\320\336\037\001\362\336\037\023yaml:\"base_account\"'
  _globals['_ETHACCOUNT'].fields_by_name['code_hash']._loaded_options = None
  _globals['_ETHACCOUNT'].fields_by_name['code_hash']._serialized_options = b'\362\336\037\020yaml:\"code_hash\"'
  _globals['_ETHACCOUNT']._loaded_options = None
  _globals['_ETHACCOUNT']._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000\312\264-\034cosmos.auth.v1beta1.AccountI'
  _globals['_ETHACCOUNT']._serialized_start=148
  _globals['_ETHACCOUNT']._serialized_end=355
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/msg/v1/msg.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63osmos/msg/v1/msg.proto\x12\rcosmos.msg.v1\x1a google/protobuf/descriptor.proto:<\n\x07service\x12\x1f.google.protobuf.ServiceOptions\x18\xf0\x8c\xa6\x05 \x01(\x08R\x07service::\n\x06signer\x12\x1f.google.protobuf.MessageOptions\x18\xf0\x8c\xa6\x05 \x03(\tR\x06signerB\xa2\x01\n\x11\x63om.cosmos.msg.v1B\x08MsgProtoP\x01Z-github.com/cosmos/cosmos-sdk/types/msgservice\xa2\x02\x03\x43MX\xaa\x02\rCosmos.Msg.V1\xca\x02\rCosmos\\Msg\\V1\xe2\x02\x19\x43osmos\\Msg\\V1\\GPBMetadata\xea\x02\x0f\x43osmos::Msg::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.msg.v1.msg_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.cosmos.msg.v1B\010MsgProtoP\001Z-github.com/cosmos/cosmos-sdk/types/msgservice\242\002\003CMX\252\002\rCosmos.Msg.V1\312\002\rCosmos\\Msg\\V1\342\002\031Cosmos\\Msg\\V1\\GPBMetadata\352\002\017Cosmos::Msg::V1'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/ocr.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1finjective/ocr/v1beta1/ocr.proto\x12\x15injective.ocr.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61mino/amino.proto\"\x93\x01\n\x06Params\x12\x1d\n\nlink_denom\x18\x01 \x01(\tR\tlinkDenom\x12\x32\n\x15payout_block_interval\x18\x02 \x01(\x04R\x13payoutBlockInterval\x12!\n\x0cmodule_admin\x18\x03 \x01(\tR\x0bmoduleAdmin:\x13\xe8\xa0\x1f\x01\x8a\xe7\xb0*\nocr/Params\"\xaa\x02\n\nFeedConfig\x12\x18\n\x07signers\x18\x01 \x03(\tR\x07signers\x12\"\n\x0ctransmitters\x18\x02 \x03(\tR\x0ctransmitters\x12\x0c\n\x01\x66\x18\x03 \x01(\rR\x01\x66\x12%\n\x0eonchain_config\x18\x04 \x01(\x0cR\ronchainConfig\x12\x36\n\x17offchain_config_version\x18\x05 \x01(\x04R\x15offchainConfigVersion\x12\'\n\x0foffchain_config\x18\x06 \x01(\x0cR\x0eoffchainConfig\x12H\n\rmodule_params\x18\x07 \x01(\x0b\x32#.injective.ocr.v1beta1.ModuleParamsR\x0cmoduleParams\"\xbe\x01\n\x0e\x46\x65\x65\x64\x43onfigInfo\x12\x30\n\x14latest_config_digest\x18\x01 \x01(\x0cR\x12latestConfigDigest\x12\x0c\n\x01\x66\x18\x02 \x01(\rR\x01\x66\x12\x0c\n\x01n\x18\x03 \x01(\rR\x01n\x12!\n\x0c\x63onfig_count\x18\x04 \x01(\x04R\x0b\x63onfigCount\x12;\n\x1alatest_config_block_number\x18\x05 \x01(\x03R\x17latestConfigBlockNumber\"\xff\x03\n\x0cModuleParams\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\x12\x42\n\nmin_answer\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tminAnswer\x12\x42\n\nmax_answer\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tmaxAnswer\x12O\n\x14link_per_observation\x18\x04 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x12linkPerObservation\x12Q\n\x15link_per_transmission\x18\x05 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x13linkPerTransmission\x12\x1d\n\nlink_denom\x18\x06 \x01(\tR\tlinkDenom\x12%\n\x0eunique_reports\x18\x07 \x01(\x08R\runiqueReports\x12 \n\x0b\x64\x65scription\x18\x08 \x01(\tR\x0b\x64\x65scription\x12\x1d\n\nfeed_admin\x18\t \x01(\tR\tfeedAdmin\x12#\n\rbilling_admin\x18\n \x01(\tR\x0c\x62illingAdmin\"\x87\x02\n\x0e\x43ontractConfig\x12!\n\x0c\x63onfig_count\x18\x01 \x01(\x04R\x0b\x63onfigCount\x12\x18\n\x07signers\x18\x02 \x03(\tR\x07signers\x12\"\n\x0ctransmitters\x18\x03 \x03(\tR\x0ctransmitters\x12\x0c\n\x01\x66\x18\x04 \x01(\rR\x01\x66\x12%\n\x0eonchain_config\x18\x05 \x01(\x0cR\ronchainConfig\x12\x36\n\x17offchain_config_version\x18\x06 \x01(\x04R\x15offchainConfigVersion\x12\'\n\x0foffchain_config\x18\x07 \x01(\x0cR\x0eoffchainConfig\"\xc8\x01\n\x11SetConfigProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x39\n\x06\x63onfig\x18\x03 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfigR\x06\x63onfig:@\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\x15ocr/SetConfigProposal\"\xb4\x04\n\x0e\x46\x65\x65\x64Properties\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\x12\x0c\n\x01\x66\x18\x02 \x01(\rR\x01\x66\x12%\n\x0eonchain_config\x18\x03 \x01(\x0cR\ronchainConfig\x12\x36\n\x17offchain_config_version\x18\x04 \x01(\x04R\x15offchainConfigVersion\x12\'\n\x0foffchain_config\x18\x05 \x01(\x0cR\x0eoffchainConfig\x12\x42\n\nmin_answer\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tminAnswer\x12\x42\n\nmax_answer\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tmaxAnswer\x12O\n\x14link_per_observation\x18\x08 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x12linkPerObservation\x12Q\n\x15link_per_transmission\x18\t \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x13linkPerTransmission\x12%\n\x0eunique_reports\x18\n \x01(\x08R\runiqueReports\x12 \n\x0b\x64\x65scription\x18\x0b \x01(\tR\x0b\x64\x65scription\"\xc4\x02\n\x16SetBatchConfigProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x18\n\x07signers\x18\x03 \x03(\tR\x07signers\x12\"\n\x0ctransmitters\x18\x04 \x03(\tR\x0ctransmitters\x12\x1d\n\nlink_denom\x18\x05 \x01(\tR\tlinkDenom\x12N\n\x0f\x66\x65\x65\x64_properties\x18\x06 \x03(\x0b\x32%.injective.ocr.v1beta1.FeedPropertiesR\x0e\x66\x65\x65\x64Properties:E\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\x1aocr/SetBatchConfigProposal\"2\n\x18OracleObservationsCounts\x12\x16\n\x06\x63ounts\x18\x01 \x03(\rR\x06\x63ounts\"V\n\x11GasReimbursements\x12\x41\n\x0ereimbursements\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinR\x0ereimbursements\"U\n\x05Payee\x12)\n\x10transmitter_addr\x18\x01 \x01(\tR\x0ftransmitterAddr\x12!\n\x0cpayment_addr\x18\x02 \x01(\tR\x0bpaymentAddr\"\xb9\x01\n\x0cTransmission\x12;\n\x06\x61nswer\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06\x61nswer\x12\x35\n\x16observations_timestamp\x18\x02 \x01(\x03R\x15observationsTimestamp\x12\x35\n\x16transmission_timestamp\x18\x03 \x01(\x03R\x15transmissionTimestamp\";\n\rEpochAndRound\x12\x14\n\x05\x65poch\x18\x01 \x01(\x04R\x05\x65poch\x12\x14\n\x05round\x18\x02 \x01(\x04R\x05round\"\xa6\x01\n\x06Report\x12\x35\n\x16observations_timestamp\x18\x01 \x01(\x03R\x15observationsTimestamp\x12\x1c\n\tobservers\x18\x02 \x01(\x0cR\tobservers\x12G\n\x0cobservations\x18\x03 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0cobservations\"\x96\x01\n\x0cReportToSign\x12#\n\rconfig_digest\x18\x01 \x01(\x0cR\x0c\x63onfigDigest\x12\x14\n\x05\x65poch\x18\x02 \x01(\x04R\x05\x65poch\x12\x14\n\x05round\x18\x03 \x01(\x04R\x05round\x12\x1d\n\nextra_hash\x18\x04 \x01(\x0cR\textraHash\x12\x16\n\x06report\x18\x05 \x01(\x0cR\x06report\"\x94\x01\n\x0f\x45ventOraclePaid\x12)\n\x10transmitter_addr\x18\x01 \x01(\tR\x0ftransmitterAddr\x12\x1d\n\npayee_addr\x18\x02 \x01(\tR\tpayeeAddr\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\"\xcc\x01\n\x12\x45ventAnswerUpdated\x12\x37\n\x07\x63urrent\x18\x01 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x07\x63urrent\x12\x38\n\x08round_id\x18\x02 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x07roundId\x12\x43\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\tupdatedAt\"\xad\x01\n\rEventNewRound\x12\x38\n\x08round_id\x18\x01 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x07roundId\x12\x1d\n\nstarted_by\x18\x02 \x01(\tR\tstartedBy\x12\x43\n\nstarted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\tstartedAt\"M\n\x10\x45ventTransmitted\x12#\n\rconfig_digest\x18\x01 \x01(\x0cR\x0c\x63onfigDigest\x12\x14\n\x05\x65poch\x18\x02 \x01(\x04R\x05\x65poch\"\xcf\x03\n\x14\x45ventNewTransmission\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\x12.\n\x13\x61ggregator_round_id\x18\x02 \x01(\rR\x11\x61ggregatorRoundId\x12;\n\x06\x61nswer\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06\x61nswer\x12 \n\x0btransmitter\x18\x04 \x01(\tR\x0btransmitter\x12\x35\n\x16observations_timestamp\x18\x05 \x01(\x03R\x15observationsTimestamp\x12G\n\x0cobservations\x18\x06 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0cobservations\x12\x1c\n\tobservers\x18\x07 \x01(\x0cR\tobservers\x12#\n\rconfig_digest\x18\x08 \x01(\x0cR\x0c\x63onfigDigest\x12L\n\x0f\x65poch_and_round\x18\t \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRoundR\repochAndRound\"\xf9\x01\n\x0e\x45ventConfigSet\x12#\n\rconfig_digest\x18\x01 \x01(\x0cR\x0c\x63onfigDigest\x12?\n\x1cprevious_config_block_number\x18\x02 \x01(\x03R\x19previousConfigBlockNumber\x12\x39\n\x06\x63onfig\x18\x03 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfigR\x06\x63onfig\x12\x46\n\x0b\x63onfig_info\x18\x04 \x01(\x0b\x32%.injective.ocr.v1beta1.FeedConfigInfoR\nconfigInfoB\xe6\x01\n\x19\x63om.injective.ocr.v1beta1B\x08OcrProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types\xa2\x02\x03IOX\xaa\x02\x15Injective.Ocr.V1beta1\xca\x02\x15Injective\\Ocr\\V1beta1\xe2\x02!Injective\\Ocr\\V1beta1\\GPBMetadata\xea\x02\x17Injective::Ocr::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.ocr.v1beta1.ocr_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective.ocr.v1beta1B\010OcrProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types\242\002\003IOX\252\002\025Injective.Ocr.V1beta1\312\002\025Injective\\Ocr\\V1beta1\342\002!Injective\\Ocr\\V1beta1\\GPBMetadata\352\002\027Injective::Ocr::V1beta1'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\nocr/Params'
  _globals['_MODULEPARAMS'].fields_by_name['min_answer']._loaded_options = None
  _globals['_MODULEPARAMS'].fields_by_name['min_answer']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MODULEPARAMS'].fields_by_name['max_answer']._loaded_options = None
  _globals['_MODULEPARAMS'].fields_by_name['max_answer']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MODULEPARAMS'].fields_by_name['link_per_observation']._loaded_options = None
  _globals['_MODULEPARAMS'].fields_by_name['link_per_observation']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_MODULEPARAMS'].fields_by_name['link_per_transmission']._loaded_options = None
  _globals['_MODULEPARAMS'].fields_by_name['link_per_transmission']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_SETCONFIGPROPOSAL']._loaded_options = None
  _globals['_SETCONFIGPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\025ocr/SetConfigProposal'
  _globals['_FEEDPROPERTIES'].fields_by_name['min_answer']._loaded_options = None
  _globals['_FEEDPROPERTIES'].fields_by_name['min_answer']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_FEEDPROPERTIES'].fields_by_name['max_answer']._loaded_options = None
  _globals['_FEEDPROPERTIES'].fields_by_name['max_answer']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_FEEDPROPERTIES'].fields_by_name['link_per_observation']._loaded_options = None
  _globals['_FEEDPROPERTIES'].fields_by_name['link_per_observation']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_FEEDPROPERTIES'].fields_by_name['link_per_transmission']._loaded_options = None
  _globals['_FEEDPROPERTIES'].fields_by_name['link_per_transmission']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_SETBATCHCONFIGPROPOSAL']._loaded_options = None
  _globals['_SETBATCHCONFIGPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\032ocr/SetBatchConfigProposal'
  _globals['_TRANSMISSION'].fields_by_name['answer']._loaded_options = None
  _globals['_TRANSMISSION'].fields_by_name['answer']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_REPORT'].fields_by_name['observations']._loaded_options = None
  _globals['_REPORT'].fields_by_name['observations']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTORACLEPAID'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTORACLEPAID'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTANSWERUPDATED'].fields_by_name['current']._loaded_options = None
  _globals['_EVENTANSWERUPDATED'].fields_by_name['current']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_EVENTANSWERUPDATED'].fields_by_name['round_id']._loaded_options = None
  _globals['_EVENTANSWERUPDATED'].fields_by_name['round_id']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_EVENTANSWERUPDATED'].fields_by_name['updated_at']._loaded_options = None
  _globals['_EVENTANSWERUPDATED'].fields_by_name['updated_at']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EVENTNEWROUND'].fields_by_name['round_id']._loaded_options = None
  _globals['_EVENTNEWROUND'].fields_by_name['round_id']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_EVENTNEWROUND'].fields_by_name['started_at']._loaded_options = None
  _globals['_EVENTNEWROUND'].fields_by_name['started_at']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EVENTNEWTRANSMISSION'].fields_by_name['answer']._loaded_options = None
  _globals['_EVENTNEWTRANSMISSION'].fields_by_name['answer']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EVENTNEWTRANSMISSION'].fields_by_name['observations']._loaded_options = None
  _globals['_EVENTNEWTRANSMISSION'].fields_by_name['observations']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PARAMS']._serialized_start=192
  _globals['_PARAMS']._serialized_end=339
  _globals['_FEEDCONFIG']._serialized_start=342
  _globals['_FEEDCONFIG']._serialized_end=640
  _globals['_FEEDCONFIGINFO']._serialized_start=643
  _globals['_FEEDCONFIGINFO']._serialized_end=833
  _globals['_MODULEPARAMS']._serialized_start=836
  _globals['_MODULEPARAMS']._serialized_end=1347
  _globals['_CONTRACTCONFIG']._serialized_start=1350
  _globals['_CONTRACTCONFIG']._serialized_end=1613
  _globals['_SETCONFIGPROPOSAL']._serialized_start=1616
  _globals['_SETCONFIGPROPOSAL']._serialized_end=1816
  _globals['_FEEDPROPERTIES']._serialized_start=1819
  _globals['_FEEDPROPERTIES']._serialized_end=2383
  _globals['_SETBATCHCONFIGPROPOSAL']._serialized_start=2386
  _globals['_SETBATCHCONFIGPROPOSAL']._serialized_end=2710
  _globals['_ORACLEOBSERVATIONSCOUNTS']._serialized_start=2712
  _globals['_ORACLEOBSERVATIONSCOUNTS']._serialized_end=2762
  _globals['_GASREIMBURSEMENTS']._serialized_start=2764
  _globals['_GASREIMBURSEMENTS']._serialized_end=2850
  _globals['_PAYEE']._serialized_start=2852
  _globals['_PAYEE']._serialized_end=2937
  _globals['_TRANSMISSION']._serialized_start=2940
  _globals['_TRANSMISSION']._serialized_end=3125
  _globals['_EPOCHANDROUND']._serialized_start=3127
  _globals['_EPOCHANDROUND']._serialized_end=3186
  _globals['_REPORT']._serialized_start=3189
  _globals['_REPORT']._serialized_end=3355
  _globals['_REPORTTOSIGN']._serialized_start=3358
  _globals['_REPORTTOSIGN']._serialized_end=3508
  _globals['_EVENTORACLEPAID']._serialized_start=3511
  _globals['_EVENTORACLEPAID']._serialized_end=3659
  _globals['_EVENTANSWERUPDATED']._serialized_start=3662
  _globals['_EVENTANSWERUPDATED']._serialized_end=3866
  _globals['_EVENTNEWROUND']._serialized_start=3869
  _globals['_EVENTNEWROUND']._serialized_end=4042
  _globals['_EVENTTRANSMITTED']._serialized_start=4044
  _globals['_EVENTTRANSMITTED']._serialized_end=4121
  _globals['_EVENTNEWTRANSMISSION']._serialized_start=4124
  _globals['_EVENTNEWTRANSMISSION']._serialized_end=4587
  _globals['_EVENTCONFIGSET']._serialized_start=4590
  _globals['_EVENTCONFIGSET']._serialized_end=4839
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/node/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/base/node/v1beta1/query.proto\x12\x18\x63osmos.base.node.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\"\x0f\n\rConfigRequest\"\xb8\x01\n\x0e\x43onfigResponse\x12*\n\x11minimum_gas_price\x18\x01 \x01(\tR\x0fminimumGasPrice\x12.\n\x13pruning_keep_recent\x18\x02 \x01(\tR\x11pruningKeepRecent\x12)\n\x10pruning_interval\x18\x03 \x01(\tR\x0fpruningInterval\x12\x1f\n\x0bhalt_height\x18\x04 \x01(\x04R\nhaltHeight\"\x0f\n\rStatusRequest\"\xde\x01\n\x0eStatusResponse\x12\x32\n\x15\x65\x61rliest_store_height\x18\x01 \x01(\x04R\x13\x65\x61rliestStoreHeight\x12\x16\n\x06height\x18\x02 \x01(\x04R\x06height\x12>\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01R\ttimestamp\x12\x19\n\x08\x61pp_hash\x18\x04 \x01(\x0cR\x07\x61ppHash\x12%\n\x0evalidator_hash\x18\x05 \x01(\x0cR\rvalidatorHash2\x99\x02\n\x07Service\x12\x85\x01\n\x06\x43onfig\x12\'.cosmos.base.node.v1beta1.ConfigRequest\x1a(.cosmos.base.node.v1beta1.ConfigResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /cosmos/base/node/v1beta1/config\x12\x85\x01\n\x06Status\x12\'.cosmos.base.node.v1beta1.StatusRequest\x1a(.cosmos.base.node.v1beta1.StatusResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /cosmos/base/node/v1beta1/statusB\xdc\x01\n\x1c\x63om.cosmos.base.node.v1beta1B\nQueryProtoP\x01Z-github.com/cosmos/cosmos-sdk/client/grpc/node\xa2\x02\x03\x43\x42N\xaa\x02\x18\x43osmos.Base.Node.V1beta1\xca\x02\x18\x43osmos\\Base\\Node\\V1beta1\xe2\x02$Cosmos\\Base\\Node\\V1beta1\\GPBMetadata\xea\x02\x1b\x43osmos::Base::Node::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.node.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.cosmos.base.node.v1beta1B\nQueryProtoP\001Z-github.com/cosmos/cosmos-sdk/client/grpc/node\242\002\003CBN\252\002\030Cosmos.Base.Node.V1beta1\312\002\030Cosmos\\Base\\Node\\V1beta1\342\002$Cosmos\\Base\\Node\\V1beta1\\GPBMetadata\352\002\033Cosmos::Base::Node::V1beta1'
  _globals['_STATUSRESPONSE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_STATUSRESPONSE'].fields_by_name['timestamp']._serialized_options = b'\220\337\037\001'
  _globals['_SERVICE'].methods_by_name['Config']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['Config']._serialized_options = b'\202\323\344\223\002\"\022 /cosmos/base/node/v1beta1/config'
  _globals['_SERVICE'].methods_by_name['Status']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['Status']._serialized_options = b'\202\323\344\223\002\"\022 /cosmos/base/node/v1beta1/status'
  _globals['_CONFIGREQUEST']._serialized_start=151
  _globals['_CONFIGREQUEST']._serialized_end=166
  _globals['_CONFIGRESPONSE']._serialized_start=169
  _globals['_CONFIGRESPONSE']._serialized_end=353
  _globals['_STATUSREQUEST']._serialized_start=355
  _globals['_STATUSREQUEST']._serialized_end=370
  _globals['_STATUSRESPONSE']._serialized_start=373
  _globals['_STATUSRESPONSE']._serialized_end=595
  _globals['_SERVICE']._serialized_start=598
  _globals['_SERVICE']._serialized_end=879
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.exchange import injective_archiver_rpc_pb2 as exchange_dot_injective__archiver__rpc__pb2


class InjectiveArchiverRPCStub(object):
    """InjectiveArchiverRPC defines gRPC API of Archiver provider.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Balance = channel.unary_unary(
                '/injective_archiver_rpc.InjectiveArchiverRPC/Balance',
                request_serializer=exchange_dot_injective__archiver__rpc__pb2.BalanceRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__archiver__rpc__pb2.BalanceResponse.FromString,
                _registered_method=True)
        self.Rpnl = channel.unary_unary(
                '/injective_archiver_rpc.InjectiveArchiverRPC/Rpnl',
                request_serializer=exchange_dot_injective__archiver__rpc__pb2.RpnlRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__archiver__rpc__pb2.RpnlResponse.FromString,
                _registered_method=True)
        self.Volumes = channel.unary_unary(
                '/injective_archiver_rpc.InjectiveArchiverRPC/Volumes',
                request_serializer=exchange_dot_injective__archiver__rpc__pb2.VolumesRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__archiver__rpc__pb2.VolumesResponse.FromString,
                _registered_method=True)
        self.PnlLeaderboard = channel.unary_unary(
                '/injective_archiver_rpc.InjectiveArchiverRPC/PnlLeaderboard',
                request_serializer=exchange_dot_injective__archiver__rpc__pb2.PnlLeaderboardRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__archiver__rpc__pb2.PnlLeaderboardResponse.FromString,
                _registered_method=True)
        self.VolLeaderboard = channel.unary_unary(
                '/injective_archiver_rpc.InjectiveArchiverRPC/VolLeaderboard',
                request_serializer=exchange_dot_injective__archiver__rpc__pb2.VolLeaderboardRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__archiver__rpc__pb2.VolLeaderboardResponse.FromString,
                _registered_method=True)
        self.PnlLeaderboardFixedResolution = channel.unary_unary(
                '/injective_archiver_rpc.InjectiveArchiverRPC/PnlLeaderboardFixedResolution',
                request_serializer=exchange_dot_injective__archiver__rpc__pb2.PnlLeaderboardFixedResolutionRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__archiver__rpc__pb2.PnlLeaderboardFixedResolutionResponse.FromString,
                _registered_method=True)
        self.VolLeaderboardFixedResolution = channel.unary_unary(
                '/injective_archiver_rpc.InjectiveArchiverRPC/VolLeaderboardFixedResolution',
                request_serializer=exchange_dot_injective__archiver__rpc__pb2.VolLeaderboardFixedResolutionRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__archiver__rpc__pb2.VolLeaderboardFixedResolutionResponse.FromString,
                _registered_method=True)
        self.DenomHolders = channel.unary_unary(
                '/injective_archiver_rpc.InjectiveArchiverRPC/DenomHolders',
                request_serializer=exchange_dot_injective__archiver__rpc__pb2.DenomHoldersRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__archiver__rpc__pb2.DenomHoldersResponse.FromString,
                _registered_method=True)
        self.HistoricalTrades = channel.unary_unary(
                '/injective_archiver_rpc.InjectiveArchiverRPC/HistoricalTrades',
                request_serializer=exchange_dot_injective__archiver__rpc__pb2.HistoricalTradesRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__archiver__rpc__pb2.HistoricalTradesResponse.FromString,
                _registered_method=True)


class InjectiveArchiverRPCServicer(object):
    """InjectiveArchiverRPC defines gRPC API of Archiver provider.
    """

    def Balance(self, request, context):
        """Provide historical balance data for a given account address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Rpnl(self, request, context):
        """Provide historical realized profit and loss data for a given account address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Volumes(self, request, context):
        """Provide historical volumes for a given account address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PnlLeaderboard(self, request, context):
        """Provide pnl leaderboard data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VolLeaderboard(self, request, context):
        """Provide volume leaderboard data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PnlLeaderboardFixedResolution(self, request, context):
        """Provide pnl leaderboard data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VolLeaderboardFixedResolution(self, request, context):
        """Provide volume leaderboard data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomHolders(self, request, context):
        """Provide a list of addresses holding a specific denom
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HistoricalTrades(self, request, context):
        """Provide historical trades data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveArchiverRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Balance': grpc.unary_unary_rpc_method_handler(
                    servicer.Balance,
                    request_deserializer=exchange_dot_injective__archiver__rpc__pb2.BalanceRequest.FromString,
                    response_serializer=exchange_dot_injective__archiver__rpc__pb2.BalanceResponse.SerializeToString,
            ),
            'Rpnl': grpc.unary_unary_rpc_method_handler(
                    servicer.Rpnl,
                    request_deserializer=exchange_dot_injective__archiver__rpc__pb2.RpnlRequest.FromString,
                    response_serializer=exchange_dot_injective__archiver__rpc__pb2.RpnlResponse.SerializeToString,
            ),
            'Volumes': grpc.unary_unary_rpc_method_handler(
                    servicer.Volumes,
                    request_deserializer=exchange_dot_injective__archiver__rpc__pb2.VolumesRequest.FromString,
                    response_serializer=exchange_dot_injective__archiver__rpc__pb2.VolumesResponse.SerializeToString,
            ),
            'PnlLeaderboard': grpc.unary_unary_rpc_method_handler(
                    servicer.PnlLeaderboard,
                    request_deserializer=exchange_dot_injective__archiver__rpc__pb2.PnlLeaderboardRequest.FromString,
                    response_serializer=exchange_dot_injective__archiver__rpc__pb2.PnlLeaderboardResponse.SerializeToString,
            ),
            'VolLeaderboard': grpc.unary_unary_rpc_method_handler(
                    servicer.VolLeaderboard,
                    request_deserializer=exchange_dot_injective__archiver__rpc__pb2.VolLeaderboardRequest.FromString,
                    response_serializer=exchange_dot_injective__archiver__rpc__pb2.VolLeaderboardResponse.SerializeToString,
            ),
            'PnlLeaderboardFixedResolution': grpc.unary_unary_rpc_method_handler(
                    servicer.PnlLeaderboardFixedResolution,
                    request_deserializer=exchange_dot_injective__archiver__rpc__pb2.PnlLeaderboardFixedResolutionRequest.FromString,
                    response_serializer=exchange_dot_injective__archiver__rpc__pb2.PnlLeaderboardFixedResolutionResponse.SerializeToString,
            ),
            'VolLeaderboardFixedResolution': grpc.unary_unary_rpc_method_handler(
                    servicer.VolLeaderboardFixedResolution,
                    request_deserializer=exchange_dot_injective__archiver__rpc__pb2.VolLeaderboardFixedResolutionRequest.FromString,
                    response_serializer=exchange_dot_injective__archiver__rpc__pb2.VolLeaderboardFixedResolutionResponse.SerializeToString,
            ),
            'DenomHolders': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomHolders,
                    request_deserializer=exchange_dot_injective__archiver__rpc__pb2.DenomHoldersRequest.FromString,
                    response_serializer=exchange_dot_injective__archiver__rpc__pb2.DenomHoldersResponse.SerializeToString,
            ),
            'HistoricalTrades': grpc.unary_unary_rpc_method_handler(
                    servicer.HistoricalTrades,
                    request_deserializer=exchange_dot_injective__archiver__rpc__pb2.HistoricalTradesRequest.FromString,
                    response_serializer=exchange_dot_injective__archiver__rpc__pb2.HistoricalTradesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_archiver_rpc.InjectiveArchiverRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective_archiver_rpc.InjectiveArchiverRPC', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class InjectiveArchiverRPC(object):
    """InjectiveArchiverRPC defines gRPC API of Archiver provider.
    """

    @staticmethod
    def Balance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_archiver_rpc.InjectiveArchiverRPC/Balance',
            exchange_dot_injective__archiver__rpc__pb2.BalanceRequest.SerializeToString,
            exchange_dot_injective__archiver__rpc__pb2.BalanceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Rpnl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_archiver_rpc.InjectiveArchiverRPC/Rpnl',
            exchange_dot_injective__archiver__rpc__pb2.RpnlRequest.SerializeToString,
            exchange_dot_injective__archiver__rpc__pb2.RpnlResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Volumes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_archiver_rpc.InjectiveArchiverRPC/Volumes',
            exchange_dot_injective__archiver__rpc__pb2.VolumesRequest.SerializeToString,
            exchange_dot_injective__archiver__rpc__pb2.VolumesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PnlLeaderboard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_archiver_rpc.InjectiveArchiverRPC/PnlLeaderboard',
            exchange_dot_injective__archiver__rpc__pb2.PnlLeaderboardRequest.SerializeToString,
            exchange_dot_injective__archiver__rpc__pb2.PnlLeaderboardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VolLeaderboard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_archiver_rpc.InjectiveArchiverRPC/VolLeaderboard',
            exchange_dot_injective__archiver__rpc__pb2.VolLeaderboardRequest.SerializeToString,
            exchange_dot_injective__archiver__rpc__pb2.VolLeaderboardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PnlLeaderboardFixedResolution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_archiver_rpc.InjectiveArchiverRPC/PnlLeaderboardFixedResolution',
            exchange_dot_injective__archiver__rpc__pb2.PnlLeaderboardFixedResolutionRequest.SerializeToString,
            exchange_dot_injective__archiver__rpc__pb2.PnlLeaderboardFixedResolutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VolLeaderboardFixedResolution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_archiver_rpc.InjectiveArchiverRPC/VolLeaderboardFixedResolution',
            exchange_dot_injective__archiver__rpc__pb2.VolLeaderboardFixedResolutionRequest.SerializeToString,
            exchange_dot_injective__archiver__rpc__pb2.VolLeaderboardFixedResolutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DenomHolders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_archiver_rpc.InjectiveArchiverRPC/DenomHolders',
            exchange_dot_injective__archiver__rpc__pb2.DenomHoldersRequest.SerializeToString,
            exchange_dot_injective__archiver__rpc__pb2.DenomHoldersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HistoricalTrades(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_archiver_rpc.InjectiveArchiverRPC/HistoricalTrades',
            exchange_dot_injective__archiver__rpc__pb2.HistoricalTradesRequest.SerializeToString,
            exchange_dot_injective__archiver__rpc__pb2.HistoricalTradesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/solomachine/v3/solomachine.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ibc/lightclients/solomachine/v3/solomachine.proto\x12\x1fibc.lightclients.solomachine.v3\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\xa6\x01\n\x0b\x43lientState\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence\x12\x1b\n\tis_frozen\x18\x02 \x01(\x08R\x08isFrozen\x12X\n\x0f\x63onsensus_state\x18\x03 \x01(\x0b\x32/.ibc.lightclients.solomachine.v3.ConsensusStateR\x0e\x63onsensusState:\x04\x88\xa0\x1f\x00\"\x8b\x01\n\x0e\x43onsensusState\x12\x33\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\tpublicKey\x12 \n\x0b\x64iversifier\x18\x02 \x01(\tR\x0b\x64iversifier\x12\x1c\n\ttimestamp\x18\x03 \x01(\x04R\ttimestamp:\x04\x88\xa0\x1f\x00\"\xaf\x01\n\x06Header\x12\x1c\n\ttimestamp\x18\x01 \x01(\x04R\ttimestamp\x12\x1c\n\tsignature\x18\x02 \x01(\x0cR\tsignature\x12:\n\x0enew_public_key\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0cnewPublicKey\x12\'\n\x0fnew_diversifier\x18\x04 \x01(\tR\x0enewDiversifier:\x04\x88\xa0\x1f\x00\"\xe0\x01\n\x0cMisbehaviour\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence\x12V\n\rsignature_one\x18\x02 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v3.SignatureAndDataR\x0csignatureOne\x12V\n\rsignature_two\x18\x03 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v3.SignatureAndDataR\x0csignatureTwo:\x04\x88\xa0\x1f\x00\"|\n\x10SignatureAndData\x12\x1c\n\tsignature\x18\x01 \x01(\x0cR\tsignature\x12\x12\n\x04path\x18\x02 \x01(\x0cR\x04path\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\x12\x1c\n\ttimestamp\x18\x04 \x01(\x04R\ttimestamp:\x04\x88\xa0\x1f\x00\"e\n\x18TimestampedSignatureData\x12%\n\x0esignature_data\x18\x01 \x01(\x0cR\rsignatureData\x12\x1c\n\ttimestamp\x18\x02 \x01(\x04R\ttimestamp:\x04\x88\xa0\x1f\x00\"\x95\x01\n\tSignBytes\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence\x12\x1c\n\ttimestamp\x18\x02 \x01(\x04R\ttimestamp\x12 \n\x0b\x64iversifier\x18\x03 \x01(\tR\x0b\x64iversifier\x12\x12\n\x04path\x18\x04 \x01(\x0cR\x04path\x12\x12\n\x04\x64\x61ta\x18\x05 \x01(\x0cR\x04\x64\x61ta:\x04\x88\xa0\x1f\x00\"q\n\nHeaderData\x12\x34\n\x0bnew_pub_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\tnewPubKey\x12\'\n\x0fnew_diversifier\x18\x02 \x01(\tR\x0enewDiversifier:\x04\x88\xa0\x1f\x00\x42\xa4\x02\n#com.ibc.lightclients.solomachine.v3B\x10SolomachineProtoP\x01ZLgithub.com/cosmos/ibc-go/v8/modules/light-clients/06-solomachine;solomachine\xa2\x02\x03ILS\xaa\x02\x1fIbc.Lightclients.Solomachine.V3\xca\x02\x1fIbc\\Lightclients\\Solomachine\\V3\xe2\x02+Ibc\\Lightclients\\Solomachine\\V3\\GPBMetadata\xea\x02\"Ibc::Lightclients::Solomachine::V3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.solomachine.v3.solomachine_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.ibc.lightclients.solomachine.v3B\020SolomachineProtoP\001ZLgithub.com/cosmos/ibc-go/v8/modules/light-clients/06-solomachine;solomachine\242\002\003ILS\252\002\037Ibc.Lightclients.Solomachine.V3\312\002\037Ibc\\Lightclients\\Solomachine\\V3\342\002+Ibc\\Lightclients\\Solomachine\\V3\\GPBMetadata\352\002\"Ibc::Lightclients::Solomachine::V3'
  _globals['_CLIENTSTATE']._loaded_options = None
  _globals['_CLIENTSTATE']._serialized_options = b'\210\240\037\000'
  _globals['_CONSENSUSSTATE']._loaded_options = None
  _globals['_CONSENSUSSTATE']._serialized_options = b'\210\240\037\000'
  _globals['_HEADER']._loaded_options = None
  _globals['_HEADER']._serialized_options = b'\210\240\037\000'
  _globals['_MISBEHAVIOUR']._loaded_options = None
  _globals['_MISBEHAVIOUR']._serialized_options = b'\210\240\037\000'
  _globals['_SIGNATUREANDDATA']._loaded_options = None
  _globals['_SIGNATUREANDDATA']._serialized_options = b'\210\240\037\000'
  _globals['_TIMESTAMPEDSIGNATUREDATA']._loaded_options = None
  _globals['_TIMESTAMPEDSIGNATUREDATA']._serialized_options = b'\210\240\037\000'
  _globals['_SIGNBYTES']._loaded_options = None
  _globals['_SIGNBYTES']._serialized_options = b'\210\240\037\000'
  _globals['_HEADERDATA']._loaded_options = None
  _globals['_HEADERDATA']._serialized_options = b'\210\240\037\000'
  _globals['_CLIENTSTATE']._serialized_start=136
  _globals['_CLIENTSTATE']._serialized_end=302
  _globals['_CONSENSUSSTATE']._serialized_start=305
  _globals['_CONSENSUSSTATE']._serialized_end=444
  _globals['_HEADER']._serialized_start=447
  _globals['_HEADER']._serialized_end=622
  _globals['_MISBEHAVIOUR']._serialized_start=625
  _globals['_MISBEHAVIOUR']._serialized_end=849
  _globals['_SIGNATUREANDDATA']._serialized_start=851
  _globals['_SIGNATUREANDDATA']._serialized_end=975
  _globals['_TIMESTAMPEDSIGNATUREDATA']._serialized_start=977
  _globals['_TIMESTAMPEDSIGNATUREDATA']._serialized_end=1078
  _globals['_SIGNBYTES']._serialized_start=1081
  _globals['_SIGNBYTES']._serialized_end=1230
  _globals['_HEADERDATA']._serialized_start=1232
  _globals['_HEADERDATA']._serialized_end=1345
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_referral_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%exchange/injective_referral_rpc.proto\x12\x16injective_referral_rpc\"F\n\x19GetReferrerDetailsRequest\x12)\n\x10referrer_address\x18\x01 \x01(\tR\x0freferrerAddress\"\xe3\x01\n\x1aGetReferrerDetailsResponse\x12\x43\n\x08invitees\x18\x01 \x03(\x0b\x32\'.injective_referral_rpc.ReferralInviteeR\x08invitees\x12)\n\x10total_commission\x18\x02 \x01(\tR\x0ftotalCommission\x12\x30\n\x14total_trading_volume\x18\x03 \x01(\tR\x12totalTradingVolume\x12#\n\rreferrer_code\x18\x04 \x01(\tR\x0creferrerCode\"\x8f\x01\n\x0fReferralInvitee\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x1e\n\ncommission\x18\x02 \x01(\tR\ncommission\x12%\n\x0etrading_volume\x18\x03 \x01(\tR\rtradingVolume\x12\x1b\n\tjoin_date\x18\x04 \x01(\tR\x08joinDate\"C\n\x18GetInviteeDetailsRequest\x12\'\n\x0finvitee_address\x18\x01 \x01(\tR\x0einviteeAddress\"\xb0\x01\n\x19GetInviteeDetailsResponse\x12\x1a\n\x08referrer\x18\x01 \x01(\tR\x08referrer\x12\x1b\n\tused_code\x18\x02 \x01(\tR\x08usedCode\x12%\n\x0etrading_volume\x18\x03 \x01(\tR\rtradingVolume\x12\x1b\n\tjoined_at\x18\x04 \x01(\tR\x08joinedAt\x12\x16\n\x06\x61\x63tive\x18\x05 \x01(\x08R\x06\x61\x63tive\"?\n\x18GetReferrerByCodeRequest\x12#\n\rreferral_code\x18\x01 \x01(\tR\x0creferralCode\"F\n\x19GetReferrerByCodeResponse\x12)\n\x10referrer_address\x18\x01 \x01(\tR\x0freferrerAddress2\x87\x03\n\x14InjectiveReferralRPC\x12{\n\x12GetReferrerDetails\x12\x31.injective_referral_rpc.GetReferrerDetailsRequest\x1a\x32.injective_referral_rpc.GetReferrerDetailsResponse\x12x\n\x11GetInviteeDetails\x12\x30.injective_referral_rpc.GetInviteeDetailsRequest\x1a\x31.injective_referral_rpc.GetInviteeDetailsResponse\x12x\n\x11GetReferrerByCode\x12\x30.injective_referral_rpc.GetReferrerByCodeRequest\x1a\x31.injective_referral_rpc.GetReferrerByCodeResponseB\xc2\x01\n\x1a\x63om.injective_referral_rpcB\x19InjectiveReferralRpcProtoP\x01Z\x19/injective_referral_rpcpb\xa2\x02\x03IXX\xaa\x02\x14InjectiveReferralRpc\xca\x02\x14InjectiveReferralRpc\xe2\x02 InjectiveReferralRpc\\GPBMetadata\xea\x02\x14InjectiveReferralRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_referral_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.injective_referral_rpcB\031InjectiveReferralRpcProtoP\001Z\031/injective_referral_rpcpb\242\002\003IXX\252\002\024InjectiveReferralRpc\312\002\024InjectiveReferralRpc\342\002 InjectiveReferralRpc\\GPBMetadata\352\002\024InjectiveReferralRpc'
  _globals['_GETREFERRERDETAILSREQUEST']._serialized_start=65
  _globals['_GETREFERRERDETAILSREQUEST']._serialized_end=135
  _globals['_GETREFERRERDETAILSRESPONSE']._serialized_start=138
  _globals['_GETREFERRERDETAILSRESPONSE']._serialized_end=365
  _globals['_REFERRALINVITEE']._serialized_start=368
  _globals['_REFERRALINVITEE']._serialized_end=511
  _globals['_GETINVITEEDETAILSREQUEST']._serialized_start=513
  _globals['_GETINVITEEDETAILSREQUEST']._serialized_end=580
  _globals['_GETINVITEEDETAILSRESPONSE']._serialized_start=583
  _globals['_GETINVITEEDETAILSRESPONSE']._serialized_end=759
  _globals['_GETREFERRERBYCODEREQUEST']._serialized_start=761
  _globals['_GETREFERRERBYCODEREQUEST']._serialized_end=824
  _globals['_GETREFERRERBYCODERESPONSE']._serialized_start=826
  _globals['_GETREFERRERBYCODERESPONSE']._serialized_end=896
  _globals['_INJECTIVEREFERRALRPC']._serialized_start=899
  _globals['_INJECTIVEREFERRALRPC']._serialized_end=1290
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.injective.ocr.v1beta1 import ocr_pb2 as injective_dot_ocr_dot_v1beta1_dot_ocr__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.injective.ocr.v1beta1 import genesis_pb2 as injective_dot_ocr_dot_v1beta1_dot_genesis__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!injective/ocr/v1beta1/query.proto\x12\x15injective.ocr.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x1finjective/ocr/v1beta1/ocr.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a#injective/ocr/v1beta1/genesis.proto\"\x14\n\x12QueryParamsRequest\"R\n\x13QueryParamsResponse\x12;\n\x06params\x18\x01 \x01(\x0b\x32\x1d.injective.ocr.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"1\n\x16QueryFeedConfigRequest\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\"\xae\x01\n\x17QueryFeedConfigResponse\x12O\n\x10\x66\x65\x65\x64_config_info\x18\x01 \x01(\x0b\x32%.injective.ocr.v1beta1.FeedConfigInfoR\x0e\x66\x65\x65\x64\x43onfigInfo\x12\x42\n\x0b\x66\x65\x65\x64_config\x18\x02 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfigR\nfeedConfig\"5\n\x1aQueryFeedConfigInfoRequest\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\"\xbc\x01\n\x1bQueryFeedConfigInfoResponse\x12O\n\x10\x66\x65\x65\x64_config_info\x18\x01 \x01(\x0b\x32%.injective.ocr.v1beta1.FeedConfigInfoR\x0e\x66\x65\x65\x64\x43onfigInfo\x12L\n\x0f\x65poch_and_round\x18\x02 \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRoundR\repochAndRound\"2\n\x17QueryLatestRoundRequest\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\"{\n\x18QueryLatestRoundResponse\x12&\n\x0flatest_round_id\x18\x01 \x01(\x04R\rlatestRoundId\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.injective.ocr.v1beta1.TransmissionR\x04\x64\x61ta\"@\n%QueryLatestTransmissionDetailsRequest\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\"\xd4\x01\n&QueryLatestTransmissionDetailsResponse\x12#\n\rconfig_digest\x18\x01 \x01(\x0cR\x0c\x63onfigDigest\x12L\n\x0f\x65poch_and_round\x18\x02 \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRoundR\repochAndRound\x12\x37\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32#.injective.ocr.v1beta1.TransmissionR\x04\x64\x61ta\":\n\x16QueryOwedAmountRequest\x12 \n\x0btransmitter\x18\x01 \x01(\tR\x0btransmitter\"R\n\x17QueryOwedAmountResponse\x12\x37\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\"\x19\n\x17QueryModuleStateRequest\"U\n\x18QueryModuleStateResponse\x12\x39\n\x05state\x18\x01 \x01(\x0b\x32#.injective.ocr.v1beta1.GenesisStateR\x05state2\xbb\t\n\x05Query\x12\x86\x01\n\x06Params\x12).injective.ocr.v1beta1.QueryParamsRequest\x1a*.injective.ocr.v1beta1.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/chainlink/ocr/v1beta1/params\x12\xa1\x01\n\nFeedConfig\x12-.injective.ocr.v1beta1.QueryFeedConfigRequest\x1a..injective.ocr.v1beta1.QueryFeedConfigResponse\"4\x82\xd3\xe4\x93\x02.\x12,/chainlink/ocr/v1beta1/feed_config/{feed_id}\x12\xb2\x01\n\x0e\x46\x65\x65\x64\x43onfigInfo\x12\x31.injective.ocr.v1beta1.QueryFeedConfigInfoRequest\x1a\x32.injective.ocr.v1beta1.QueryFeedConfigInfoResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/chainlink/ocr/v1beta1/feed_config_info/{feed_id}\x12\xa5\x01\n\x0bLatestRound\x12..injective.ocr.v1beta1.QueryLatestRoundRequest\x1a/.injective.ocr.v1beta1.QueryLatestRoundResponse\"5\x82\xd3\xe4\x93\x02/\x12-/chainlink/ocr/v1beta1/latest_round/{feed_id}\x12\xde\x01\n\x19LatestTransmissionDetails\x12<.injective.ocr.v1beta1.QueryLatestTransmissionDetailsRequest\x1a=.injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse\"D\x82\xd3\xe4\x93\x02>\x12</chainlink/ocr/v1beta1/latest_transmission_details/{feed_id}\x12\xa5\x01\n\nOwedAmount\x12-.injective.ocr.v1beta1.QueryOwedAmountRequest\x1a..injective.ocr.v1beta1.QueryOwedAmountResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/chainlink/ocr/v1beta1/owed_amount/{transmitter}\x12\x9e\x01\n\x0eOcrModuleState\x12..injective.ocr.v1beta1.QueryModuleStateRequest\x1a/.injective.ocr.v1beta1.QueryModuleStateResponse\"+\x82\xd3\xe4\x93\x02%\x12#/chainlink/ocr/v1beta1/module_stateB\xe8\x01\n\x19\x63om.injective.ocr.v1beta1B\nQueryProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types\xa2\x02\x03IOX\xaa\x02\x15Injective.Ocr.V1beta1\xca\x02\x15Injective\\Ocr\\V1beta1\xe2\x02!Injective\\Ocr\\V1beta1\\GPBMetadata\xea\x02\x17Injective::Ocr::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.ocr.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective.ocr.v1beta1B\nQueryProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types\242\002\003IOX\252\002\025Injective.Ocr.V1beta1\312\002\025Injective\\Ocr\\V1beta1\342\002!Injective\\Ocr\\V1beta1\\GPBMetadata\352\002\027Injective::Ocr::V1beta1'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYOWEDAMOUNTRESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_QUERYOWEDAMOUNTRESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\037\022\035/chainlink/ocr/v1beta1/params'
  _globals['_QUERY'].methods_by_name['FeedConfig']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FeedConfig']._serialized_options = b'\202\323\344\223\002.\022,/chainlink/ocr/v1beta1/feed_config/{feed_id}'
  _globals['_QUERY'].methods_by_name['FeedConfigInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FeedConfigInfo']._serialized_options = b'\202\323\344\223\0023\0221/chainlink/ocr/v1beta1/feed_config_info/{feed_id}'
  _globals['_QUERY'].methods_by_name['LatestRound']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LatestRound']._serialized_options = b'\202\323\344\223\002/\022-/chainlink/ocr/v1beta1/latest_round/{feed_id}'
  _globals['_QUERY'].methods_by_name['LatestTransmissionDetails']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LatestTransmissionDetails']._serialized_options = b'\202\323\344\223\002>\022</chainlink/ocr/v1beta1/latest_transmission_details/{feed_id}'
  _globals['_QUERY'].methods_by_name['OwedAmount']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OwedAmount']._serialized_options = b'\202\323\344\223\0022\0220/chainlink/ocr/v1beta1/owed_amount/{transmitter}'
  _globals['_QUERY'].methods_by_name['OcrModuleState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OcrModuleState']._serialized_options = b'\202\323\344\223\002%\022#/chainlink/ocr/v1beta1/module_state'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=214
  _globals['_QUERYPARAMSREQUEST']._serialized_end=234
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=236
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=318
  _globals['_QUERYFEEDCONFIGREQUEST']._serialized_start=320
  _globals['_QUERYFEEDCONFIGREQUEST']._serialized_end=369
  _globals['_QUERYFEEDCONFIGRESPONSE']._serialized_start=372
  _globals['_QUERYFEEDCONFIGRESPONSE']._serialized_end=546
  _globals['_QUERYFEEDCONFIGINFOREQUEST']._serialized_start=548
  _globals['_QUERYFEEDCONFIGINFOREQUEST']._serialized_end=601
  _globals['_QUERYFEEDCONFIGINFORESPONSE']._serialized_start=604
  _globals['_QUERYFEEDCONFIGINFORESPONSE']._serialized_end=792
  _globals['_QUERYLATESTROUNDREQUEST']._serialized_start=794
  _globals['_QUERYLATESTROUNDREQUEST']._serialized_end=844
  _globals['_QUERYLATESTROUNDRESPONSE']._serialized_start=846
  _globals['_QUERYLATESTROUNDRESPONSE']._serialized_end=969
  _globals['_QUERYLATESTTRANSMISSIONDETAILSREQUEST']._serialized_start=971
  _globals['_QUERYLATESTTRANSMISSIONDETAILSREQUEST']._serialized_end=1035
  _globals['_QUERYLATESTTRANSMISSIONDETAILSRESPONSE']._serialized_start=1038
  _globals['_QUERYLATESTTRANSMISSIONDETAILSRESPONSE']._serialized_end=1250
  _globals['_QUERYOWEDAMOUNTREQUEST']._serialized_start=1252
  _globals['_QUERYOWEDAMOUNTREQUEST']._serialized_end=1310
  _globals['_QUERYOWEDAMOUNTRESPONSE']._serialized_start=1312
  _globals['_QUERYOWEDAMOUNTRESPONSE']._serialized_end=1394
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=1396
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=1421
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=1423
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=1508
  _globals['_QUERY']._serialized_start=1511
  _globals['_QUERY']._serialized_end=2722
# @@protoc_insertion_point(module_scope)



from typing import Dict, List

import aiohttp

from pyinjective.core.token import Token
from pyinjective.utils.logger import LoggerProvider


class TokensFileLoader:
    def load_json(self, json: List[Dict]) -> List[Token]:
        loaded_tokens = []

        for token_info in json:
            token = Token(
                name=token_info["name"],
                symbol=token_info["symbol"],
                denom=token_info["denom"],
                address=token_info.get("address", ""),
                decimals=token_info["decimals"],
                logo=token_info["logo"],
                updated=-1,
            )

            loaded_tokens.append(token)

        return loaded_tokens

    async def load_tokens(self, tokens_file_url: str) -> List[Token]:
        tokens_list = []
        try:
            async with aiohttp.ClientSession() as session:
                async with session.get(tokens_file_url) as response:
                    if response.ok:
                        tokens_list = await response.json(content_type=None)
        except Exception as e:
            LoggerProvider().logger_for_class(logging_class=self.__class__).warning(
                f"there was an error fetching the list of official tokens: {e}"
            )

        return self.load_json(tokens_list)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/ics23/v1/proofs.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/ics23/v1/proofs.proto\x12\x0f\x63osmos.ics23.v1\"\x93\x01\n\x0e\x45xistenceProof\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\x12+\n\x04leaf\x18\x03 \x01(\x0b\x32\x17.cosmos.ics23.v1.LeafOpR\x04leaf\x12,\n\x04path\x18\x04 \x03(\x0b\x32\x18.cosmos.ics23.v1.InnerOpR\x04path\"\x91\x01\n\x11NonExistenceProof\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12\x33\n\x04left\x18\x02 \x01(\x0b\x32\x1f.cosmos.ics23.v1.ExistenceProofR\x04left\x12\x35\n\x05right\x18\x03 \x01(\x0b\x32\x1f.cosmos.ics23.v1.ExistenceProofR\x05right\"\x93\x02\n\x0f\x43ommitmentProof\x12\x37\n\x05\x65xist\x18\x01 \x01(\x0b\x32\x1f.cosmos.ics23.v1.ExistenceProofH\x00R\x05\x65xist\x12@\n\x08nonexist\x18\x02 \x01(\x0b\x32\".cosmos.ics23.v1.NonExistenceProofH\x00R\x08nonexist\x12\x33\n\x05\x62\x61tch\x18\x03 \x01(\x0b\x32\x1b.cosmos.ics23.v1.BatchProofH\x00R\x05\x62\x61tch\x12G\n\ncompressed\x18\x04 \x01(\x0b\x32%.cosmos.ics23.v1.CompressedBatchProofH\x00R\ncompressedB\x07\n\x05proof\"\xf8\x01\n\x06LeafOp\x12+\n\x04hash\x18\x01 \x01(\x0e\x32\x17.cosmos.ics23.v1.HashOpR\x04hash\x12\x38\n\x0bprehash_key\x18\x02 \x01(\x0e\x32\x17.cosmos.ics23.v1.HashOpR\nprehashKey\x12<\n\rprehash_value\x18\x03 \x01(\x0e\x32\x17.cosmos.ics23.v1.HashOpR\x0cprehashValue\x12\x31\n\x06length\x18\x04 \x01(\x0e\x32\x19.cosmos.ics23.v1.LengthOpR\x06length\x12\x16\n\x06prefix\x18\x05 \x01(\x0cR\x06prefix\"f\n\x07InnerOp\x12+\n\x04hash\x18\x01 \x01(\x0e\x32\x17.cosmos.ics23.v1.HashOpR\x04hash\x12\x16\n\x06prefix\x18\x02 \x01(\x0cR\x06prefix\x12\x16\n\x06suffix\x18\x03 \x01(\x0cR\x06suffix\"\xf9\x01\n\tProofSpec\x12\x34\n\tleaf_spec\x18\x01 \x01(\x0b\x32\x17.cosmos.ics23.v1.LeafOpR\x08leafSpec\x12\x39\n\ninner_spec\x18\x02 \x01(\x0b\x32\x1a.cosmos.ics23.v1.InnerSpecR\tinnerSpec\x12\x1b\n\tmax_depth\x18\x03 \x01(\x05R\x08maxDepth\x12\x1b\n\tmin_depth\x18\x04 \x01(\x05R\x08minDepth\x12\x41\n\x1dprehash_key_before_comparison\x18\x05 \x01(\x08R\x1aprehashKeyBeforeComparison\"\xf1\x01\n\tInnerSpec\x12\x1f\n\x0b\x63hild_order\x18\x01 \x03(\x05R\nchildOrder\x12\x1d\n\nchild_size\x18\x02 \x01(\x05R\tchildSize\x12*\n\x11min_prefix_length\x18\x03 \x01(\x05R\x0fminPrefixLength\x12*\n\x11max_prefix_length\x18\x04 \x01(\x05R\x0fmaxPrefixLength\x12\x1f\n\x0b\x65mpty_child\x18\x05 \x01(\x0cR\nemptyChild\x12+\n\x04hash\x18\x06 \x01(\x0e\x32\x17.cosmos.ics23.v1.HashOpR\x04hash\"C\n\nBatchProof\x12\x35\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1b.cosmos.ics23.v1.BatchEntryR\x07\x65ntries\"\x90\x01\n\nBatchEntry\x12\x37\n\x05\x65xist\x18\x01 \x01(\x0b\x32\x1f.cosmos.ics23.v1.ExistenceProofH\x00R\x05\x65xist\x12@\n\x08nonexist\x18\x02 \x01(\x0b\x32\".cosmos.ics23.v1.NonExistenceProofH\x00R\x08nonexistB\x07\n\x05proof\"\x96\x01\n\x14\x43ompressedBatchProof\x12?\n\x07\x65ntries\x18\x01 \x03(\x0b\x32%.cosmos.ics23.v1.CompressedBatchEntryR\x07\x65ntries\x12=\n\rlookup_inners\x18\x02 \x03(\x0b\x32\x18.cosmos.ics23.v1.InnerOpR\x0clookupInners\"\xae\x01\n\x14\x43ompressedBatchEntry\x12\x41\n\x05\x65xist\x18\x01 \x01(\x0b\x32).cosmos.ics23.v1.CompressedExistenceProofH\x00R\x05\x65xist\x12J\n\x08nonexist\x18\x02 \x01(\x0b\x32,.cosmos.ics23.v1.CompressedNonExistenceProofH\x00R\x08nonexistB\x07\n\x05proof\"\x83\x01\n\x18\x43ompressedExistenceProof\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\x12+\n\x04leaf\x18\x03 \x01(\x0b\x32\x17.cosmos.ics23.v1.LeafOpR\x04leaf\x12\x12\n\x04path\x18\x04 \x03(\x05R\x04path\"\xaf\x01\n\x1b\x43ompressedNonExistenceProof\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12=\n\x04left\x18\x02 \x01(\x0b\x32).cosmos.ics23.v1.CompressedExistenceProofR\x04left\x12?\n\x05right\x18\x03 \x01(\x0b\x32).cosmos.ics23.v1.CompressedExistenceProofR\x05right*\x96\x01\n\x06HashOp\x12\x0b\n\x07NO_HASH\x10\x00\x12\n\n\x06SHA256\x10\x01\x12\n\n\x06SHA512\x10\x02\x12\r\n\tKECCAK256\x10\x03\x12\r\n\tRIPEMD160\x10\x04\x12\x0b\n\x07\x42ITCOIN\x10\x05\x12\x0e\n\nSHA512_256\x10\x06\x12\x0f\n\x0b\x42LAKE2B_512\x10\x07\x12\x0f\n\x0b\x42LAKE2S_256\x10\x08\x12\n\n\x06\x42LAKE3\x10\t*\xab\x01\n\x08LengthOp\x12\r\n\tNO_PREFIX\x10\x00\x12\r\n\tVAR_PROTO\x10\x01\x12\x0b\n\x07VAR_RLP\x10\x02\x12\x0f\n\x0b\x46IXED32_BIG\x10\x03\x12\x12\n\x0e\x46IXED32_LITTLE\x10\x04\x12\x0f\n\x0b\x46IXED64_BIG\x10\x05\x12\x12\n\x0e\x46IXED64_LITTLE\x10\x06\x12\x14\n\x10REQUIRE_32_BYTES\x10\x07\x12\x14\n\x10REQUIRE_64_BYTES\x10\x08\x42\xa2\x01\n\x13\x63om.cosmos.ics23.v1B\x0bProofsProtoP\x01Z github.com/cosmos/ics23/go;ics23\xa2\x02\x03\x43IX\xaa\x02\x0f\x43osmos.Ics23.V1\xca\x02\x0f\x43osmos\\Ics23\\V1\xe2\x02\x1b\x43osmos\\Ics23\\V1\\GPBMetadata\xea\x02\x11\x43osmos::Ics23::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.ics23.v1.proofs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.cosmos.ics23.v1B\013ProofsProtoP\001Z github.com/cosmos/ics23/go;ics23\242\002\003CIX\252\002\017Cosmos.Ics23.V1\312\002\017Cosmos\\Ics23\\V1\342\002\033Cosmos\\Ics23\\V1\\GPBMetadata\352\002\021Cosmos::Ics23::V1'
  _globals['_HASHOP']._serialized_start=2335
  _globals['_HASHOP']._serialized_end=2485
  _globals['_LENGTHOP']._serialized_start=2488
  _globals['_LENGTHOP']._serialized_end=2659
  _globals['_EXISTENCEPROOF']._serialized_start=50
  _globals['_EXISTENCEPROOF']._serialized_end=197
  _globals['_NONEXISTENCEPROOF']._serialized_start=200
  _globals['_NONEXISTENCEPROOF']._serialized_end=345
  _globals['_COMMITMENTPROOF']._serialized_start=348
  _globals['_COMMITMENTPROOF']._serialized_end=623
  _globals['_LEAFOP']._serialized_start=626
  _globals['_LEAFOP']._serialized_end=874
  _globals['_INNEROP']._serialized_start=876
  _globals['_INNEROP']._serialized_end=978
  _globals['_PROOFSPEC']._serialized_start=981
  _globals['_PROOFSPEC']._serialized_end=1230
  _globals['_INNERSPEC']._serialized_start=1233
  _globals['_INNERSPEC']._serialized_end=1474
  _globals['_BATCHPROOF']._serialized_start=1476
  _globals['_BATCHPROOF']._serialized_end=1543
  _globals['_BATCHENTRY']._serialized_start=1546
  _globals['_BATCHENTRY']._serialized_end=1690
  _globals['_COMPRESSEDBATCHPROOF']._serialized_start=1693
  _globals['_COMPRESSEDBATCHPROOF']._serialized_end=1843
  _globals['_COMPRESSEDBATCHENTRY']._serialized_start=1846
  _globals['_COMPRESSEDBATCHENTRY']._serialized_end=2020
  _globals['_COMPRESSEDEXISTENCEPROOF']._serialized_start=2023
  _globals['_COMPRESSEDEXISTENCEPROOF']._serialized_end=2154
  _globals['_COMPRESSEDNONEXISTENCEPROOF']._serialized_start=2157
  _globals['_COMPRESSEDNONEXISTENCEPROOF']._serialized_end=2332
# @@protoc_insertion_point(module_scope)
